$!
$! GNUPLOT make program for VMS, Vers. 1.2, 1996/07/03
$! (Rolf Niepraschk, niepraschk@ptb.de)
$!
$! This command procedure compiles and links GNUPLOT with MMS or MMK or
$! invokes the dcl procedure BUILDVMS.COM
$!
$!
$! Reworked by Martin P.J. Zinser (MPJZ - zinser@decus.de) for Gnuplot 3.7.3
$!
$! make_vms.com accepts the following options in arbitrary order
$!
$! DEBUG - Build a DEBUG version of Gnuplot
$!
$! CCOPT=value - Pass value as option to C compiler
$!
$! LOPTS=value - Pass value as option to the Linker
$!
$! CC=<DECC||VAXC||GNUC> - Override automatic compiler detection and force
$!                         usage of a specific compiler
$!
$ on error then goto err_exit
$!
$! Just some general constants...
$!
$ true  = 1
$ false = 0
$ tmpnam = "temp_" + f$getjpi("","pid")
$ tt = tmpnam + ".txt"
$ tc = tmpnam + ".c"
$ SAY = "WRITE SYS$OUTPUT"
$!
$! Setup variables holding "config" information
$!
$ Make    = ""
$ name    = "GNUplot"
$ version = "3.7.3"
$ xlibs    = ""
$ liblist  = ""
$ libdefs  = ""
$ libincs  = ""
$ ccopt    = ""
$ lopts    = ""
$ linkonly = false
$ optfile = name + ".opt"
$ aconf_in_file = "config.hin"
$! Check for MMK/MMS
$!
$ If F$Search ("Sys$System:MMS.EXE") .nes. "" Then Make = "MMS"
$ If F$Type (MMK) .eqs. "STRING" Then Make = "MMK"
$!
$! Look for the compiler used
$!
$ gosub check_compiler
$!
$ ccopt = "/NOLIST"
$ if its_decc
$ then
$   ccopt = "/prefix=(all,except=(erf,erfc))" + ccopt
$   if f$getsyi("HW_MODEL").lt.1024 !VAX
$   then 
$     ccopt = "/DECC" + ccopt  
$     if f$trnlnm("SYS").eqs."" then -
        define sys decc$library_include:
$   else
$     if f$trnlnm("SYS").eqs."" then define sys sys$library: 
$   endif
$ else
$   if f$trnlnm("SYS").eqs."" then define sys sys$library:
$ endif
$ gosub check_opts
$ gosub crea_depf
$!
$!      Build the option-files
$!
$ open/write optf x11.opt
$ gosub check_xlib
$ if       its_gnuc then write optf "_assert.obj"
$ if       its_gnuc then write optf "gnu_cc:[000000]gcclib/lib" 
$ if .not. its_decc then write optf "sys$library:vaxcrtl/share"
$ close optf
$ open/write optf uopt.opt
$ if       its_gnuc then write optf "_assert.obj"
$ if       its_gnuc then write optf "gnu_cc:[000000]gcclib/lib" 
$ if .not. its_decc then write optf "sys$library:vaxcrtl/share"
$ close optf
$ open/write optf 'optfile'
$!
$ open/read/err=depf_err depf_in vms_modules.txt
$DEPF_LOOP: 
$ read/end_of_file=depf_exit depf_in line
$ objf = f$element(0," ",line)
$ write optf objf
$ goto depf_loop
$DEPF_EXIT:
$ close depf_in
$ if its_gnuc then write optf  "_assert.obj"
$ write optf "Identification=""''NAME' ''VERSION'"""
$ gosub check_create_vmslib
$ if       its_gnuc then write optf  "gnu_cc:[000000]gcclib/lib" 
$ if .not. its_decc then write optf  "sys$library:vaxcrtl/share"
$!
$!
$! Input config file might be mapped in different ways, so go figure
$!
$ i = 0
$FIND_ACONF:
$ fname = f$element(i,"#",aconf_in_file)
$ if fname .eqs. "#" then goto AMISS_ERR
$ if f$search(fname) .eqs. ""
$ then 
$   i = i + 1
$   goto find_aconf
$ endif
$ open/read/err=aconf_err aconf_in 'fname'
$ open/write aconf config.h
$ACONF_LOOP:
$ read/end_of_file=aconf_exit aconf_in line
$ work = f$edit(line, "compress,trim")
$ if ((f$extract(0,6,work) .nes. "#undef") .and. - 
      (f$extract(0,7,work) .nes. "#define"))
$ then
$   write aconf line
$ else
$   def = f$element(1," ",work)
$   gosub check_config
$ endif
$ goto aconf_loop
$ACONF_EXIT:
$ write aconf "#define NO_GIH 1"
$ close aconf_in
$ close aconf
$ close optf
$!
$ defs = "HAVE_CONFIG_H," + f$extract(0,f$length(libdefs),libdefs) - ","
$ incs = "[.TERM]," + f$extract(0,f$length(libincs),libincs) - ","
$ ccopt = ccopt +  "/define=(''defs')" + "/include=(''incs')"
$!
$ IF Make .nes. ""
$ THEN
$   gosub crea_mms
$   SAY "Make Gnuplot with ''Make' "
$   SAY ""
$   'Make'  /IGNORE=WARNING
$   delete/nolog/noconf ccop.mms;*,descrip.fdl;*
$   purge/nolog descrip.mms
$ ELSE
$   SAY "Make Gnuplot directly"
$   SAY ""
$   set verify
$   cc 'ccopt' alloc.c
$   cc 'ccopt' binary.c
$   cc 'ccopt' bitmap.c
$   cc 'ccopt' command.c
$   cc 'ccopt' contour.c
$   cc 'ccopt' datafile.c
$   cc 'ccopt' eval.c
$   cc 'ccopt' fit.c
$   cc 'ccopt' graphics.c
$   cc 'ccopt' graph3d.c
$   cc 'ccopt' help.c
$   cc 'ccopt' hidden3d.c
$   cc 'ccopt' internal.c
$   cc 'ccopt' interpol.c
$   cc 'ccopt' matrix.c
$   cc 'ccopt' misc.c
$   cc 'ccopt' parse.c
$   cc 'ccopt' plot.c
$   cc 'ccopt' plot2d.c
$   cc 'ccopt' plot3d.c
$   cc 'ccopt' scanner.c
$   cc 'ccopt' set.c
$   cc 'ccopt' show.c
$   cc 'ccopt' specfun.c
$   cc 'ccopt' standard.c
$   cc 'ccopt' stdfn.c
$   cc 'ccopt' term.c
$   cc 'ccopt' time.c
$   cc 'ccopt' util.c
$   cc 'ccopt' util3d.c
$   cc 'ccopt' version.c
$   cc 'ccopt' vms.c
$   if its_gnuc then cc 'ccopt' GNU_CC_INCLUDE:[000000]_assert.c
$   link /exe=gnuplot.exe gnuplot.opt/opt
$!
$   cc 'ccopt' bf_test.c
$   link /exe=bf_test bf_test,binary,alloc 'extralib''LINKOPT'
$!
$   CC 'ccopt' GPLT_X11
$   CC 'ccopt' stdfn.c
$   LINK /exe=GNUPLOT_X11 gplt_x11,stdfn,x11.opt/OPT
$!
$   SET DEF [.DOCS]
$   if f$locate("ALL_TERM_DOC",CFLAGS).ne.f$length(CFLAGS) then -
    	  copy /concatenate [-.term]*.trm []allterm.h
$   cc 'ccopt' /OBJ=doc2rnh.obj /include=([],[-],[-.term]) doc2rnh.c 
$   cc 'ccopt' /OBJ=doc2tex.obj /include=([],[-],[-.term]) doc2tex.c 
$   cc 'ccopt' /OBJ=doc2html.obj/include=([],[-],[-.term]) doc2html.c 
$   cc 'ccopt' /OBJ=termdoc.obj /include=([],[-],[-.term]) termdoc.c 
$   cc 'ccopt' /OBJ=xref.obj    /include=([],[-],[-.term]) xref.c 
$   SET DEF [-] 	  ! LINKOPT is defined as being in []
$   link [.docs]doc2rnh.obj,termdoc.obj /exe=[.docs]doc2rnh  'extralib''LINKOPT'
$   link [.docs]doc2tex.obj,termdoc.obj /exe=[.docs]doc2tex  'extralib''LINKOPT'
$   link [.docs]doc2html.obj,termdoc.obj,xref.obj -
                                        /exe=[.docs]doc2html 'extralib''LINKOPT'
$   doc2rnh := $sys$disk:[.docs]doc2rnh
$   doc2rnh [.docs]gnuplot.doc [.docs]gnuplot.rnh
$   RUNOFF [.docs]gnuplot.rnh
$   library/create/help sys$disk:[]gnuplot.hlb gnuplot.hlp
$   doc2tex := $sys$disk:[.docs]doc2rnh
$   doc2tex [.docs]gnuplot.doc [.docs]gnuplot.rnh
$   doc2html := $sys$disk:[.docs]doc2html
$   doc2html [.docs]gnuplot.doc [.docs]gnuplot.html
$!
$   set default [.demo]
$   run [-]bf_test
$   set default [-]
$   write sys$output "%define GNUPLOT_X11 :== $Disk:[directory]GNUPLOT_X11"
$!
$ ENDIF
$ EXIT
$ACONF_ERR:
$ write sys$output "Input file ''fname' could not be opened"
$ goto err_exit
$AMISS_ERR:
$ write sys$output "No source for config.h found."
$ write sys$output "Tried any of ''aconf_in_file'"
$CC_ERR:
$ write sys$output "C compiler required to build ''name'"
$ goto err_exit
$ACONF_ERR:
$ write sys$output "Input file vms_modules.txt could not be opened"
$ goto err_exit
$ERR_EXIT:
$ set message/facil/ident/sever/text
$ delete/nolog/noconf ccop.mms;*,descrip.fdl;*
$ purge/nolog descrip.mms
$ close/nolog aconf_in
$ close/nolog aconf
$ close/nolog  depf_in
$ close/nolog optf
$ close/nolog optf
$ close/nolog tmpc
$ write sys$output "Exiting..."
$ exit 2
$!------------------------------------------------------------------------------
$!
$! Look for the compiler used
$!
$CHECK_COMPILER:
$ its_decc = (f$search("SYS$SYSTEM:DECC$COMPILER.EXE") .nes. "")
$ its_vaxc = .not. its_decc .and. (F$Search("SYS$System:VAXC.Exe") .nes. "")
$ its_gnuc = .not. (its_decc .or. its_vaxc) .and. (f$trnlnm("gnu_cc") .nes. "")
$!
$! Exit if no compiler available
$!
$ if (.not. (its_decc .or. its_vaxc .or. its_gnuc)) then goto CC_ERR
$ if its_gnuc then cc := GCC/NOCASE
$ return
$!------------------------------------------------------------------------------
$!
$! Check command line options and set symbols accordingly
$!
$ CHECK_OPTS:
$ i = 1
$ OPT_LOOP:
$ if i .lt. 9
$ then
$   cparm = f$edit(p'i',"upcase")
$   if cparm .eqs. "DEBUG"
$   then
$     ccopt = ccopt + "/noopt/deb"
$     lopts = lopts + "/deb"
$   endif
$   if f$locate("CCOPT",cparm) .lt. f$length(cparm)
$   then
$     start = f$locate("=",cparm) + 1
$     len   = f$length(cparm) - start
$     ccopt = ccopt + f$extract(start,len,cparm)
$   endif
$   if cparm .eqs. "LINK" then linkonly = true
$   if f$locate("LOPTS",cparm) .lt. f$length(cparm) 
$   then
$     start = f$locate("=",cparm) + 1
$     len   = f$length(cparm) - start
$     lopts = lopts + f$extract(start,len,cparm)
$   endif
$   if f$locate("CC",cparm) .lt. f$length(cparm)
$   then
$     start = f$locate("=",cparm) + 1
$     len   = f$length(cparm) - start
$     comp = f$extract(start,len,cparm)
$     if ((comp .eqs. "DECC") .or. (comp .eqs. "VAXC") .or. (comp .eqs. "GNUC"))
$     then
$!      Override automatic detection
$       its_decc = 0
$       its_vaxc = 0
$       its_gnuc = 0 
$       its_'comp' = 1
$     else
$       write sys$output "Invalid compiler ''comp' ignored"
$       write sys$output "Acceptable values: DECC, VAXC, GNUC"
$     endif
$   endif 
$   i = i + 1
$   goto opt_loop
$ endif
$ return
$!------------------------------------------------------------------------------
$!
$! Take care of driver file with information about external libraries
$!
$CHECK_CONFIG:
$!
$ in_ldef = f$locate(def,libdefs)
$ if (in_ldef .lt. f$length(libdefs))
$ then
$   write aconf "#define ''def' 1"
$   libdefs = f$extract(0,in_ldef,libdefs) + -
              f$extract(in_ldef + f$length(def) + 1, -
	                f$length(libdefs) - in_ldef - f$length(def) - 1, -
			libdefs) 
$ else
$   if (def .eqs. "X11")
$   then
$     write aconf "#define X11 1"
$   else
$     gosub check_cc_def
$   endif
$ endif
$ return
$!------------------------------------------------------------------------------
$!
$! Check if this is a define relating to the properties of the C/C++
$! compiler
$!
$CHECK_CC_DEF:
$ if (def .eqs. "HAVE_BZERO")
$ then
$   copy sys$input: 'tc
$   deck
#include <strings.h>
#include <stdlib.h>
int main(){
  char * s;
  s = malloc(1);
  bzero (s, 1);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_ERF")
$ then
$   copy sys$input: 'tc
$   deck
#include <math.h>
int main(){
  erf(3.1415926);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_ERFC")
$ then
$   copy sys$input: 'tc
$   deck
#include <math.h>
int main(){
  erfc(3.1415926);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_ERRNO_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <errno.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_FLOAT_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <float.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_GETCWD")
$ then
$   copy sys$input: 'tc
$   deck
#include <unistd.h>
int main(){
  char mydir[255];
  getcwd(mydir,sizeof(mydir));
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_LGAMMA")
$ then
$   copy sys$input: 'tc
$   deck
#include <math.h>

int main(){
double y;
  y = lgamma(3.141);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_LIMITS_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <limits.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_MATH_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <math.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_MEMCPY")
$ then
$   copy sys$input: 'tc
$   deck
#include <string.h>
#include <stdlib.h>
int main(){
  char * a ;
  a = malloc(1);
  memcpy (a, "A", 1);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_MEMSET")
$ then
$   copy sys$input: 'tc
$   deck
#include <string.h>
#include <stdlib.h>

int main(){
  char * s;
  s = malloc(1);
  memset (s, 1, 1);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_POPEN") .or. (def .eqs. "HAVE_PCLOSE") .or. -
     (def .eqs. "PIPES")
$ then
$   copy sys$input: 'tc
$   deck
#include <stdio.h>

int main(){
FILE *pipe;
 pipe = popen("DIR","r");
 pclose(pipe);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif     
$ if (def .eqs. "HAVE_SLEEP")
$ then
$   copy sys$input: 'tc
$   deck
#include <unistd.h>

int main(){
  sleep(1);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_STDLIB_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <stdlib.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_STRCHR")
$ then
$   copy sys$input: 'tc
$   deck
#include <string.h>
int main(){
  strchr("ABC",'A');
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_STRERROR")
$ then
$   copy sys$input: 'tc
$   deck
#include <string.h>
int main(){
  strerror(1);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_STRINGIZE")
$ then
$   copy sys$input: 'tc
$   deck
#define x(y) #y

int main(){
  char *s = x(teststring);
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_STRSTR")
$ then
$   copy sys$input: 'tc
$   deck
#include <string.h>
int main(){
  strstr("A","ABC");
}
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_STRING_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <string.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_TIME_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <time.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_TIME_T_IN_TIME_H")
#include <time.h>

int main(){
  time_t timer;
}
$ then
$   copy sys$input: 'tc
$   deck
#include <time.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "HAVE_UNISTD_H")
$ then
$   copy sys$input: 'tc
$   deck
#include <unistd.h>
$   eod
$   gosub cc_prop_check
$   return
$ endif
$ if (def .eqs. "STDC_HEADERS")
$ then
$   if (its_decc) then write aconf "#define ''def' 1"
$   return
$ endif
$ write aconf "/* ", line, " */" 
$ return
$!
$!------------------------------------------------------------------------------
$!
$! Check for properties of C/C++ compiler
$!
$CC_PROP_CHECK:
$ cc_prop = false
$ set message/nofac/noident/nosever/notext
$ cc 'tmpnam'
$ if $status then cc_prop = true
$ set message/fac/ident/sever/text
$ delete/nolog 'tmpnam'.*;*
$ if cc_prop 
$ then
$   write aconf "#define ''def' 1"
$ else 
$   write aconf line
$ endif
$ return
$!------------------------------------------------------------------------------
$!
$! Check Xlibs and write to options file
$!
$CHECK_XLIB:
$ If F$Type (xlibs) .nes. "STRING" Then xlibs = ""
$ need_xt  = f$locate("XT",f$edit(xlibs,"upcase"))    .lt. f$length(xlibs)
$ need_xmu = f$locate("XMU",f$edit(xlibs,"upcase"))   .lt. f$length(xlibs)
$ need_xm  = f$locate("MOTIF",f$edit(xlibs,"upcase")) .lt. f$length(xlibs)
$ On Error Then GoTo XUI
$ @sys$update:decw$get_image_version sys$share:decw$xlibshr.exe decw$version
$ if f$extract(4,3,decw$version).eqs."1.0"
$ then
$   if need_xt .or. need_xmu then -
      write optf "Sys$share:DECW$DWTLIBSHR.EXE/Share"
$ endif
$ if f$extract(4,3,decw$version).eqs."1.1"
$ then
$   if need_xm  then write optf "sys$share:decw$xmlibshr.exe/share"
$   if need_xt  then write optf "sys$share:decw$xtshr.exe/share"
$   if nedd_xmu then write optf "sys$share:decw$xmulibshr.exe/share"
$ endif
$ if f$extract(4,3,decw$version).eqs."1.2"
$ then
$   if need_xm  then write optf "sys$share:decw$xmlibshr12.exe/share"
$   if need_xt  then write optf "sys$share:decw$xtlibshrr5.exe/share"
$   if need_xmu then write optf "sys$share:decw$xmulibshrr5.exe/share"
$ endif
$ GoTo MAIN
$ XUI:
$!
$! Either this is a very old X-Installation or DECwindows is not installed
$!
$ if f$search("sys$share:decw$xlibshr.exe") .eqs. "" then goto X11_ERR
$ if need_xt .or. need_xmu then -
      write optf "Sys$share:DECW$DWTLIBSHR.EXE/Share"
$ MAIN:
$ on error then goto err_exit
$ write optf "sys$share:decw$xlibshr.exe/share"
$ if f$trnlnm("X11") .eqs. "" then define x11 DECW$INCLUDE
$ return
$!------------------------------------------------------------------------------
$!
$! Take care of driver file with information about external libraries
$!
$CHECK_CREATE_VMSLIB:
$!
$ if f$search("VMSLIB.DAT") .eqs. ""
$ then
$   type/out=vmslib.dat sys$input
!
! This is a simple driver file with information used by vms_make.com to
! check if external libraries (like t1lib and freetype) are available on
! the system.
!
! Layout of the file:
!
!    - Lines starting with ! are treated as comments
!    - Elements in a data line are separated by # signs
!    - The elements need to be listed in the following order
!      1.) Name of the Library (only used for informative messages
!                               from vms_make.com)
!      2.) Location where the object library can be found
!      3.) Location where the include files for the library can be found
!      4.) Include file used to verify library location
!      5.) CPP define to pass to the build to indicate availability of
!          the library
!
! Example: The following  lines show how definitions
!          might look like. They are site specific and the locations of the
!          library and include files need almost certainly to be changed.
!
! Location: All of the libaries can be found at the following addresses
!
!   LIBPNG:     http://www.decus.de:8080/www/vms/sw/libpng.htmlx
!   ZLIB:       http://www.decus.de:8080/www/vms/sw/zlib.htmlx
!
!PNG      # pubbin:libpng.olb   # public$root:[util.libs.libpng]            # png.h      # HAVE_LIBPNG,HAVE_PNG_H
!ZLIB     # pubbin:libz.olb     # public$root:[util.libs.zlib]              # zlib.h     # HAVE_ZLIB_H
$   write sys$output "New driver file vmslib.dat created."
$   write sys$output "Please customize libary locations for your site"
$   write sys$output "and afterwards re-execute vms_make.com"
$   write sys$output "Exiting..."
$   close/nolog optf
$   exit
$ endif
$!
$! Open data file with location of libraries
$!
$ open/read/end=end_lib/err=err_lib libdata VMSLIB.DAT
$LIB_LOOP:
$ read/end=end_lib libdata libline
$ libline = f$edit(libline, "UNCOMMENT,COLLAPSE")
$ if libline .eqs. "" then goto LIB_LOOP ! Comment line
$ libname = f$edit(f$element(0,"#",libline),"UPCASE")
$ write sys$output "Processing ''libname' setup ..."
$ libloc  = f$element(1,"#",libline)
$ libsrc  = f$element(2,"#",libline)
$ testinc = f$element(3,"#",libline)
$ cppdef  = f$element(4,"#",libline)
$ old_cpp = f$locate("=1",cppdef)
$ if old_cpp.lt.f$length(cppdef) then cppdef = f$extract(0,old_cpp,cppdef)
$ if f$search("''libloc'").eqs. ""
$ then
$   write sys$output "Can not find library ''libloc' - Skipping ''libname'"
$   goto LIB_LOOP
$ endif
$ libsrc_elem = 0
$ libsrc_found = false
$LIBSRC_LOOP:
$ libsrcdir = f$element(libsrc_elem,",",libsrc)
$ if (libsrcdir .eqs. ",") then goto END_LIBSRC
$ if f$search("''libsrcdir'''testinc'") .nes. "" then libsrc_found = true
$ libsrc_elem = libsrc_elem + 1
$ goto LIBSRC_LOOP
$END_LIBSRC:
$ if .not. libsrc_found
$ then
$   write sys$output "Can not find includes at ''libsrc' - Skipping ''libname'"
$   goto LIB_LOOP
$ endif
$ if cppdef .nes. "" then libdefs = libdefs +  cppdef + ","
$ libincs = libincs + "," + libsrc
$ lqual = "/lib"
$ libtype = f$edit(f$parse(libloc,,,"TYPE"),"UPCASE")
$ if f$locate("EXE",libtype) .lt. f$length(libtype) then lqual = "/share"
$ write optf libloc , lqual
$ goto LIB_LOOP
$END_LIB:
$ close libdata
$ return
$!------------------------------------------------------------------------------
$!
$! Create file with dependencies
$!
$CREA_DEPF:
$ write sys$output "Creating vms_modules.txt..."
$ copy sys$input: vms_modules.txt
$ deck
alloc.obj : alloc.c
binary.obj : binary.c
bitmap.obj : bitmap.c
command.obj : command.c
contour.obj : contour.c
datafile.obj : datafile.c
eval.obj : eval.c
fit.obj : fit.c
graphics.obj : graphics.c
graph3d.obj : graph3d.c
help.obj : help.c
hidden3d.obj : hidden3d.c
internal.obj : internal.c
interpol.obj : interpol.c
matrix.obj : matrix.c
misc.obj : misc.c
parse.obj : parse.c
plot.obj : plot.c
plot2d.obj : plot2d.c
plot3d.obj : plot3d.c
scanner.obj : scanner.c
set.obj : set.c
show.obj : show.c
specfun.obj : specfun.c
standard.obj : standard.c
stdfn.obj : stdfn.c
term.obj : term.c
time.obj : time.c
util.obj : util.c
util3d.obj : util3d.c
version.obj : version.c
vms.obj : vms.c
$ eod
$ return
$!------------------------------------------------------------------------------
$!
$! If MMS/MMK are available dump out the descrip.mms if required
$!
$CREA_MMS:
$ write sys$output "Creating descrip.mms..."
$ copy sys$input: descrip.mms
$ deck
#
# $Id: makefile.vms,v 1.4.2.4 2002/01/26 18:55:01 lhecking Exp $
#
# GNUPLOT Makefile for VMS
#
# use with the MAKE that was posted by Tony Ivanov (tony@gvgpvd.GVG.TEK.COM)
# in comp.os.vms on 5 December 1988
#
# Modified 23 June 1999 to work with MMK; it should also work with MMS.
# John.Hasstedt@sunysb.edu.
#
# You can define a macro on the command line to specify the compiler, either
# VAXC or GNUC; if you do not specify either, it uses DECC.  If you are
# compiling on Alpha, you should also define __ALPHA__ (MMK does this for you,
# for MMS, use MMS/DESCRIP=MAKEFILE.VMS/MACRO=__ALPHA__).
#
# Updated for Gnuplot 3.7.3 and new VMS build environment by MPJZ
#
########### COMPILE OPTIONS ###########


#maybe ABJ and AXE if that's your local convention for alpha
#(that's how I build vax and axp programs in same directory)
O=OBJ
X=EXE

# NOOP  NO Optimiser

############## okay, that's enough fiddling ###############

OBJS1 = alloc.$(O),binary.$(O),bitmap.$(O),command.$(O),contour.$(O),datafile.$(O),eval.$(O),
OBJS2 = fit.$(O),graphics.$(O),graph3d.$(O),help.$(O),hidden3d.$(O),internal.$(O),interpol.$(O),
OBJS3 = matrix.$(O),misc.$(O),parse.$(O),plot.$(O),plot2d.$(O),plot3d.$(O),scanner.$(O),set.$(O),
OBJS4 = show.$(O),specfun.$(O),standard.$(O),stdfn.$(O),term.$(O),time.$(O),util.$(O),util3d.$(O),version.$(O),vms.$(O)
OBJS = $(OBJS1)$(OBJS2)$(OBJS3)$(OBJS4)

CSOURCE1 = command.c set.c show.c
CSOURCE2 = help.c graphics.c graph3d.c internal.c
CSOURCE3 = misc.c eval.c parse.c plot.c plot2d.c plot3d.c scanner.c standard.c stdfn.c
CSOURCE4 = bitmap.c term.c time.c util.c version.c interpol.c fit.c matrix.c
CSOURCE5 = [.term]aed.trm [.term]cgi.trm [.term]dumb.trm [.term]dxf.trm [.term]dxy.trm \
	[.term]eepic.trm [.term]epson.trm [.term]fig.trm [.term]hp26.trm \
	[.term]hp2648.trm [.term]hpgl.trm [.term]hpljii.trm
CSOURCE6 = [.term]impcodes.h [.term]imagen.trm [.term]object.h \
	[.term]iris4d.trm [.term]kyo.trm [.term]latex.trm [.term]pbm.trm  \
	[.term]pdf.trm [.term]pc.trm
CSOURCE7 = [.term]post.trm [.term]qms.trm [.term]regis.trm [.term]sun.trm \
	[.term]svg.trm [.term]t410x.trm [.term]tek.trm [.term]unixpc.trm \
	[.term]unixplot.trm [.term]v384.trm [.term]x11.trm gplt_x11.c
CSOURCE8 = contour.c specfun.c interpol.c vms.c

all :   gnuplot.$(X) gnuplot_x11.$(X) gnuplot.hlp gnuplot.hlb  gnuplot.html\
        gnuplot.dvi [.demo]binary1.
	@	! a no-op to suppress a MMS warning

gnuplot.$(X) : $(OBJS) 
	link /exe=gnuplot.$(X) gnuplot.opt/opt
gnuplot_x11.$(X) : gplt_x11.$(O) stdfn.$(O)
	link /exe=gnuplot_x11.$(X) gplt_x11.$(O),stdfn.$(O),x11.opt/option

gplt_x11.o : gplt_x11.c
	$(CC) $(CFLAGS) $(X11FLAGS)

[.demo]binary1. [.demo]binary2. [.demo]binary3. : bf_test.$(X)
	set default [.demo]
	run [-]bf_test.$(X)
	set default [-]

bf_test.$(X) : bf_test.$(O) binary.$(O) alloc.$(O)
	link /exe=bf_test.exe bf_test.$(O),binary.$(O),alloc.$(O)

gnuplot.hlb : gnuplot.hlp
        library/create/help gnuplot.hlb gnuplot.hlp

.IFDEF OLD_HLP
gnuplot.hlp : doc2hlp.$(X) [.docs]gnuplot.doc
	define/user sys$input [.docs]gnuplot.doc
	define/user sys$output []gnuplot.hlp
	run doc2hlp

doc2hlp.$(X) : [.docs]doc2hlp.c [.docs]termdoc.c
	$(CC) /include=([.docs],[],[.term]) [.docs]doc2hlp.c,[.docs]termdoc.c
	link /exe=doc2hlp.$(X) doc2hlp,termdoc,[]uopt.opt/options
.ELSE
gnuplot.hlp : [.docs]gnuplot.rnh
        RUNOFF $< /OUTPUT=$@

[.docs]gnuplot.rnh : [.docs]doc2rnh.$(X) [.docs]gnuplot.doc
        MCR $< [.docs]gnuplot.doc $@

[.docs]doc2rnh.$(X) : [.docs]doc2rnh.$(O) [.docs]termdoc.$(O)
        link /exe=$@  $+ ,[]uopt.opt/options

[.docs]doc2rnh.$(O) [.docs]termdoc.$(O) : [.docs]termdoc.c ![.docs]allterm.h
        $(CC) /OBJ=$@ $(CFLAGS) /INCLUDE=([],[.TERM]) $*.c

gnuplot.html : [.docs]doc2html.$(X) [.docs]gnuplot.doc
        mcr $< [.docs]gnuplot.doc $@

[.docs]gnuplot.tex : [.docs]doc2tex.$(X) [.docs]gnuplot.doc
        mcr $< [.docs]gnuplot.doc $@

gnuplot.dvi : [.docs]gnuplot.tex [.docs]titlepag.tex [.docs]toc_entr.sty
        $set def  [.docs]
        LATEX $*
        LATEX $*
        RENAME $@ [-]$@
        $set def [-]

[.docs]doc2html.$(X) : [.docs]doc2html.$(O) [.docs]termdoc.$(O) [.docs]xref.$(O)
        link /exe=$@  $+ ,[]uopt.opt/options
	
[.docs]doc2html.$(O)  :  [.docs]doc2html.c	
	$(CC) /OBJ=$@ $(CFLAGS) /INCLUDE=([],[.TERM]) $*.c

[.docs]xref.$(O)  :  [.docs]xref.c	
	$(CC) /OBJ=$@ $(CFLAGS) /INCLUDE=([],[.TERM]) $*.c
	
[.docs]doc2tex.$(X) : [.docs]doc2tex.$(O) [.docs]termdoc.$(O)
        link /exe=$@  $+ ,[]uopt.opt/options

[.docs]doc2tex.$(O)  :  [.docs]doc2tex.c	
	$(CC) /OBJ=$@ $(CFLAGS) /INCLUDE=([],[.TERM]) $*.c

.ENDIF

term.$(O) : term.h term.c $(CSOURCE5) $(CSOURCE6) $(CSOURCE7)
	$(CC) $(CFLAGS) $(TERMFLAGS) term.c /object=term.$(O)

$(OBJS) : plot.h

command.$(O) help.$(O) misc.$(O) : help.h

command.$(O) graphics.$(O) graph3d.$(O) misc.$(O) plot.$(O) set.$(O) show.$(O) term.O interpol.$(O) : setshow.h

command.$(O) fit.$(O) matrix.$(O) : fit.h

fit.$(O) matrix.$(O) : matrix.h

bitmap.$(O) term.$(O) : bitmap.h

clean :
	purge/log
	delete/log *.$(O);*
	delete/log [.demo]binary1.;*,binary2.;*,binary3.;*
$ eod
$ anal/rms/fdl descrip.mms
$ open/write mmsf ccop.mms
$ write mmsf "CFLAGS = ", ccopt
$ close mmsf
$ convert/fdl=descrip.fdl ccop.mms ccop.mms
$ copy ccop.mms,descrip.mms;-1 descrip.mms
$ return
$!------------------------------------------------------------------------------
